@@ -25,6 +25,7 @@ warning = "INPUT IS NOT ASCII"
 warning_2 = "PARAPHRASE MUST BE AN INTEGER"
 bool_ascii_in_stay = True
 bool_crypt_spaces = True
+caesar = 0
 
 class Caesar_Engine(object):
 
@@ -269,7 +270,7 @@ class Ui_MainWindow(object):
         self.checkBox.setText(_translate("MainWindow", "Stay in ASCII letters only a-z and A-Z will be crypted", None))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.Caesar), _translate("MainWindow", "Caesar", None))
         self.label_6.setText(_translate("MainWindow", "crypt_me", None))
-        self.label_7.setText(_translate("MainWindow", "version 0.13", None))
+        self.label_7.setText(_translate("MainWindow", "version 0.14", None))
         self.label_8.setText(_translate("MainWindow", "programming language: python 2.7", None))
         self.label_9.setText(_translate("MainWindow", "GUI: PyQt4", None))
         self.label_15.setText(_translate("MainWindow", "Generate Paraphrase - generate random paraphrase (random int number)", None))
@@ -343,6 +344,7 @@ def main():
     ui = Ui_MainWindow()
     ui.setupUi(MainWindow)
     MainWindow.show()
+    global caesar
     caesar = Caesar_Engine()
     sys.exit(app.exec_())
 
